package com.zd.chemical.mapper;

import java.util.List;
import com.zd.chemical.domain.HxpStock;
import com.zd.chemical.domain.vo.*;
import org.apache.ibatis.annotations.Param;

/**
 * 库存管理Mapper接口
 *
 * @author liubo
 * @date 2022-06-17
 */
public interface HxpStockMapper
{
    /**
     * 查询库存管理
     *
     * @param id 库存管理主键
     * @return 库存管理
     */
    public HxpStock selectHxpStockById(Long id);

    /**
     * 查询库存管理列表
     *
     * @param hxpStock 库存管理
     * @return 库存管理集合
     */
    public List<HxpStock> selectHxpStockList(HxpStock hxpStock);


    /**
     * 查询库存管理列表
     *
     * @param hxpStockSearch 库存管理
     * @return 库存管理集合
     */
    public List<HxpStockDetailVO> selectHxpStockListDetail(HxpStockSearch hxpStockSearch);

    /**
     * 查询库存管理列表
     *
     * @param hxpStockSearch 库存管理
     * @return 库存管理集合
     */
    public List<HxpStockJoinVO> selectHxpStockListJoin(HxpStockSearch hxpStockSearch);

    /**
     * 查询库存管理列表
     *
     * @param hxpStockSearch 库存管理
     * @return 库存管理集合
     */
    public List<HxpStockOutVO> selectHxpStockListOut(HxpStockSearch hxpStockSearch);

    /**
     * 新增库存管理
     *
     * @param hxpStock 库存管理
     * @return 结果
     */
    public int insertHxpStock(HxpStock hxpStock);

    /**
     * 修改库存管理
     *
     * @param hxpStock 库存管理
     * @return 结果
     */
    public int updateHxpStock(HxpStock hxpStock);

    /**
     * 删除库存管理
     *
     * @param id 库存管理主键
     * @return 结果
     */
    public int deleteHxpStockById(Long id);

    /**
     * 批量删除库存管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHxpStockByIds(Long[] ids);

    int selectCountByTagCode(String tagCode);

    HxpStock selectByRfidCode(String rfidCode);

    int selectCountByRfidCode(HxpStock hxpStock);

    List<HxpStockVO> selectStockByExpired();

    int updateExpiredByIds(@Param("list") List<Long> stockIds);
}
